"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SwfTextEditorController = exports.SwfTextEditorOperation = void 0;
var monaco_editor_1 = require("monaco-editor");
var editor_1 = require("@kie-tools/serverless-workflow-language-service/dist/editor");
var json_1 = require("./augmentation/language/json");
var yaml_1 = require("./augmentation/language/yaml");
var operating_system_1 = require("@kie-tools-core/operating-system");
var api_1 = require("@kie-tools-core/editor/dist/api");
(0, json_1.initJsonSchemaDiagnostics)();
(0, yaml_1.initYamlSchemaDiagnostics)();
var SwfTextEditorOperation;
(function (SwfTextEditorOperation) {
    SwfTextEditorOperation[SwfTextEditorOperation["UNDO"] = 0] = "UNDO";
    SwfTextEditorOperation[SwfTextEditorOperation["REDO"] = 1] = "REDO";
    SwfTextEditorOperation[SwfTextEditorOperation["EDIT"] = 2] = "EDIT";
})(SwfTextEditorOperation = exports.SwfTextEditorOperation || (exports.SwfTextEditorOperation = {}));
var SwfTextEditorController = (function () {
    function SwfTextEditorController(content, onContentChange, language, operatingSystem, isReadOnly, setValidationErrors, fileName) {
        var _this = this;
        if (fileName === void 0) { fileName = ""; }
        this.onContentChange = onContentChange;
        this.language = language;
        this.operatingSystem = operatingSystem;
        this.isReadOnly = isReadOnly;
        this.setValidationErrors = setValidationErrors;
        this.fileName = fileName;
        this.getValidationMarkers = function () {
            return monaco_editor_1.editor.getModelMarkers({});
        };
        this.model = monaco_editor_1.editor.createModel(content, this.language);
        this.model.onDidChangeContent(function (event) {
            var _a;
            if (!event.isUndoing && !event.isRedoing) {
                (_a = _this.editor) === null || _a === void 0 ? void 0 : _a.pushUndoStop();
                onContentChange(_this.model.getValue(), SwfTextEditorOperation.EDIT);
            }
        });
        monaco_editor_1.editor.onDidChangeMarkers(function () {
            _this.setValidationErrors(_this.getValidationMarkers());
        });
        this.swfOffsetsApi = this.language === editor_1.FileLanguage.JSON ? new editor_1.SwfJsonOffsets() : new editor_1.SwfYamlOffsets();
    }
    SwfTextEditorController.prototype.redo = function () {
        var _a, _b;
        (_a = this.editor) === null || _a === void 0 ? void 0 : _a.focus();
        (_b = this.editor) === null || _b === void 0 ? void 0 : _b.trigger("editor", "redo", null);
    };
    SwfTextEditorController.prototype.undo = function () {
        var _a, _b;
        (_a = this.editor) === null || _a === void 0 ? void 0 : _a.focus();
        (_b = this.editor) === null || _b === void 0 ? void 0 : _b.trigger("editor", "undo", null);
    };
    SwfTextEditorController.prototype.setTheme = function (theme) {
        monaco_editor_1.editor.setTheme(this.getMonacoThemeByEditorTheme(theme));
    };
    SwfTextEditorController.prototype.show = function (container, theme) {
        var _this = this;
        if (!container) {
            throw new Error("We need a container to show the editor!");
        }
        if (this.editor !== undefined) {
            this.setTheme(theme);
            return this.editor;
        }
        this.editor = monaco_editor_1.editor.create(container, {
            model: this.model,
            language: this.language,
            scrollBeyondLastLine: false,
            automaticLayout: true,
            fontSize: 12,
            theme: this.getMonacoThemeByEditorTheme(theme),
            readOnly: this.isReadOnly,
        });
        this.editor.addCommand(monaco_editor_1.KeyMod.CtrlCmd | monaco_editor_1.KeyCode.KeyZ, function () {
            _this.onContentChange(_this.model.getValue(), SwfTextEditorOperation.UNDO);
        });
        this.editor.addCommand(monaco_editor_1.KeyMod.CtrlCmd | monaco_editor_1.KeyMod.Shift | monaco_editor_1.KeyCode.KeyZ, function () {
            _this.onContentChange(_this.model.getValue(), SwfTextEditorOperation.REDO);
        });
        if (this.operatingSystem !== operating_system_1.OperatingSystem.MACOS) {
            this.editor.addCommand(monaco_editor_1.KeyMod.CtrlCmd | monaco_editor_1.KeyCode.KeyY, function () {
                _this.onContentChange(_this.model.getValue(), SwfTextEditorOperation.REDO);
            });
        }
        return this.editor;
    };
    SwfTextEditorController.prototype.getContent = function () {
        var _a, _b;
        return ((_b = (_a = this.editor) === null || _a === void 0 ? void 0 : _a.getModel()) === null || _b === void 0 ? void 0 : _b.getValue()) || "";
    };
    SwfTextEditorController.prototype.forceRedraw = function () {
        var _a;
        (_a = this.editor) === null || _a === void 0 ? void 0 : _a.render(true);
    };
    SwfTextEditorController.prototype.moveCursorToNode = function (nodeName) {
        var _a, _b, _c, _d;
        if (!this.editor || !nodeName) {
            return;
        }
        this.swfOffsetsApi.parseContent(this.getContent());
        var targetOffset = this.swfOffsetsApi.getStateNameOffset(nodeName);
        if (!targetOffset) {
            return;
        }
        var targetPosition = (_b = (_a = this.editor) === null || _a === void 0 ? void 0 : _a.getModel()) === null || _b === void 0 ? void 0 : _b.getPositionAt(targetOffset);
        if (!targetPosition) {
            return;
        }
        (_c = this.editor) === null || _c === void 0 ? void 0 : _c.revealLineInCenter(targetPosition.lineNumber);
        (_d = this.editor) === null || _d === void 0 ? void 0 : _d.setPosition(targetPosition);
    };
    SwfTextEditorController.prototype.getMonacoThemeByEditorTheme = function (theme) {
        switch (theme) {
            case api_1.EditorTheme.DARK:
                return "vs-dark";
            case api_1.EditorTheme.HIGH_CONTRAST:
                return "hc-black";
            default:
                return "vs";
        }
    };
    SwfTextEditorController.prototype.dispose = function () {
        var _a;
        (_a = this.editor) === null || _a === void 0 ? void 0 : _a.dispose();
    };
    return SwfTextEditorController;
}());
exports.SwfTextEditorController = SwfTextEditorController;
//# sourceMappingURL=SwfTextEditorController.js.map